@@ -1,17 +1,23 @@
 import copy
 import json
-from typing import List, Literal, Optional, Union
+from typing import (
+    Literal,
+    Optional,
+    Union
+)
 
-from fastf1.req import Cache
 import fastf1.ergast.structure as API
-from fastf1.version import __version__
+from fastf1 import __version_short__
+from fastf1.internals.pandas_base import (
+    BaseDataFrame,
+    BaseSeries
+)
+from fastf1.req import Cache
 
 
-import pandas as pd
-
-
-BASE_URL = 'https://ergast.com/api/f1'
-HEADERS = {'User-Agent': f'FastF1/{__version__}'}
+BASE_URL = 'https://api.jolpi.ca/ergast/f1'
+TIMEOUT = 5.0
+HEADERS = {'User-Agent': f'FastF1/{__version_short__}'}
 
 
 class ErgastResponseMixin:
@@ -101,7 +107,7 @@ class ErgastResponseMixin:
         )
 
 
-class ErgastResultFrame(pd.DataFrame):
+class ErgastResultFrame(BaseDataFrame):
     """
     Wraps a Pandas ``DataFrame``. Additionally, this class can be
     initialized from Ergast response data with automatic flattening and type
@@ -110,14 +116,14 @@ class ErgastResultFrame(pd.DataFrame):
     Args:
         data: Passed through to the DataFrame constructor (must be None if
             `response` is provided)
-        category: Reference to a category from :mod:`fastf1.ergast.structure`
+        category: Reference to a category from ``fastf1.ergast.structure``
             that describes the result data
         response: JSON-like response data from Ergast; used to generate `data`
             from an Ergast response (must be None if `data` is provided)
         auto_cast: Determines if values are automatically cast to the most
             appropriate data type from their original string representation
     """
-    _internal_names = pd.DataFrame._internal_names + ['base_class_view']
+    _internal_names = BaseDataFrame._internal_names + ['base_class_view']
     _internal_names_set = set(_internal_names)
 
     def __init__(self, data=None, *,
@@ -164,48 +170,17 @@ class ErgastResultFrame(pd.DataFrame):
         return nested, flat
 
     @property
-    def _constructor(self):
-        def _new(*args, **kwargs):
-            return ErgastResultFrame(*args, **kwargs).__finalize__(self)
-
-        return _new
-
-    @property
-    def _constructor_sliced(self):
-        def _new(*args, **kwargs):
-            name = kwargs.get('name')
-            if name and (name in self.columns):
-                # vertical slice
-                return pd.Series(*args, **kwargs).__finalize__(self)
-
-            # horizontal slice
-            return ErgastResultSeries(*args, **kwargs).__finalize__(self)
-
-        return _new
-
-    @property
-    def base_class_view(self):
-        """For a nicer debugging experience; can view DataFrame through
-        this property in various IDEs"""
-        return pd.DataFrame(self)
+    def _constructor_sliced_horizontal(self):
+        return ErgastResultSeries
 
 
-class ErgastResultSeries(pd.Series):
+class ErgastResultSeries(BaseSeries):
     """
     Wraps a Pandas ``Series``.
 
     Currently, no extra functionality is implemented.
     """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    @property
-    def _constructor(self):
-        def _new(*args, **kwargs):
-            return ErgastResultSeries(*args, **kwargs).__finalize__(self)
-
-        return _new
+    pass
 
 
 class ErgastRawResponse(ErgastResponseMixin, list):
@@ -223,11 +198,12 @@ class ErgastRawResponse(ErgastResponseMixin, list):
     :class:`ErgastResponseMixin`.
 
     Args:
-        category: Reference to a category from :mod:`fastf1.ergast.structure`
+        category: Reference to a category from ``fastf1.ergast.structure``
             that describes the result data
         auto_cast: Determines if values are automatically cast to the most
             appropriate data type from their original string representation
     """
+
     def __init__(self, *, query_result, category, auto_cast, **kwargs):
         if auto_cast:
             query_result = self._prepare_response(query_result, category)
@@ -274,6 +250,13 @@ class ErgastSimpleResponse(ErgastResponseMixin, ErgastResultFrame):
         + ErgastResponseMixin._internal_names
     _internal_names_set = set(_internal_names)
 
+    @property
+    def _constructor(self) -> type["ErgastResultFrame"]:
+        # drop from ErgastSimpleResponse to ErgastResultFrame, removing the
+        # ErgastResponseMixin because a slice of the data is no longer a full
+        # response and pagination, ... is therefore not supported anymore
+        return ErgastResultFrame
+
 
 class ErgastMultiResponse(ErgastResponseMixin):
     """
@@ -344,13 +327,14 @@ class ErgastMultiResponse(ErgastResponseMixin):
             information (only data that is available in :attr:`.description`)
         response_data: A list of the "content" data that has been split from
             the Ergast response (data that is available in :attr:`.content`)
-        category: A category object from :mod:`fastf1.ergast.structure`
+        category: A category object from ``fastf1.ergast.structure``
             that defines the main category.
-        subcategory: A category object from :mod:`fastf1.ergast.structure`
+        subcategory: A category object from ``fastf1.ergast.structure``
             that defines the subcategory which is the content data.
         auto_cast: Flag that enables or disables automatic casting from the
             original string representation to the most suitable data type.
     """
+
     def __init__(self, *args,
                  response_description: dict,
                  response_data: list,
@@ -378,7 +362,7 @@ class ErgastMultiResponse(ErgastResponseMixin):
         return self._description
 
     @property
-    def content(self) -> List[ErgastResultFrame]:
+    def content(self) -> list[ErgastResultFrame]:
         """A ``list`` of :class:`ErgastResultFrame` that contain the main
         response data.
 
@@ -393,8 +377,7 @@ class Ergast:
     The main object that acts as an interface to the Ergast API.
 
     For each API endpoint, there is a separate method implemented to
-    request data. All methods have in common, that they can be preceded by a
-    call to :func:`.select` to filter the results.
+    request data.
 
     Args:
         result_type: Determines the default type of the returned result object
@@ -410,6 +393,7 @@ class Ergast:
             30 if not set. Maximum: 1000. See also "Response Paging" on
             https://ergast.com/mrd/.
     """
+
     def __init__(self,
                  result_type: Literal['raw', 'pandas'] = 'pandas',
                  auto_cast: bool = True,
@@ -440,41 +424,61 @@ class Ergast:
             selectors.append(f"/{season}")
         if round is not None:
             selectors.append(f"/{round}")
-        if circuit is not None:
-            selectors.append(f"/circuits/{circuit}")
-        if constructor is not None:
-            selectors.append(f"/constructors/{constructor}")
-        if driver is not None:
-            selectors.append(f"/drivers/{driver}")
         if grid_position is not None:
             selectors.append(f"/grid/{grid_position}")
-        if results_position is not None:
-            selectors.append(f"/results/{results_position}")
         if fastest_rank is not None:
             selectors.append(f"/fastest/{fastest_rank}")
-        if status is not None:
-            selectors.append(f"/status/{status}")
 
         # some special cases: the endpoint may also be used as selector
         # therefore, if the specifier is defined, do not add the endpoint
         # string additionally
+        if driver is not None:
+            if endpoint == 'drivers':
+                endpoint = f"drivers/{driver}"
+            else:
+                selectors.append(f"/drivers/{driver}")
+
+        if constructor is not None:
+            if endpoint == 'constructors':
+                endpoint = f"constructors/{constructor}"
+            else:
+                selectors.append(f"/constructors/{constructor}")
+
+        if circuit is not None:
+            if endpoint == 'circuits':
+                endpoint = f"circuits/{circuit}"
+            else:
+                selectors.append(f"/circuits/{circuit}")
+
+        if status is not None:
+            if endpoint == 'status':
+                endpoint = f"status/{status}"
+            else:
+                selectors.append(f"/status/{status}")
+
         if standings_position is not None:
             if endpoint == 'driverStandings':
-                selectors.append(f"/driverStandings/{standings_position}")
-                endpoint = None
+                endpoint = f"driverStandings/{standings_position}"
             elif endpoint == 'constructorStandings':
-                selectors.append(f"/constructorStandings/{standings_position}")
-                endpoint = None
+                endpoint = f"constructorStandings/{standings_position}"
+
+        if results_position is not None:
+            if endpoint in ('results', 'qualifying', 'sprint'):
+                endpoint = f"{endpoint}/{results_position}"
+            else:
+                selectors.append(f"/results/{results_position}")
 
         if lap_number is not None:
-            selectors.append(f"/laps/{lap_number}")
             if endpoint == 'laps':
-                endpoint = None
+                endpoint = f"laps/{lap_number}"
+            else:
+                selectors.append(f"/laps/{lap_number}")
 
         if stop_number is not None:
-            selectors.append(f"/pitstops/{stop_number}")
             if endpoint == 'pitstops':
-                endpoint = None
+                endpoint = f"pitstops/{stop_number}"
+            else:
+                selectors.append(f"/pitstops/{stop_number}")
 
         if endpoint is not None:
             selectors.append(f"/{endpoint}")
@@ -484,7 +488,8 @@ class Ergast:
     @classmethod
     def _get(cls, url: str, params: dict) -> Union[dict, list]:
         # request data from ergast and load the returned json data.
-        r = Cache.requests_get(url, headers=HEADERS, params=params)
+        r = Cache.requests_get(url, headers=HEADERS, params=params,
+                               timeout=TIMEOUT)
         if r.status_code == 200:
             try:
                 return json.loads(r.content.decode('utf-8'))
@@ -846,7 +851,7 @@ class Ergast:
                      'fastest_rank': fastest_rank,
                      'status': status}
 
-        return self._build_default_result(endpoint='constructors',
+        return self._build_default_result(endpoint="constructors",
                                           table='ConstructorTable',
                                           category=API.Constructors,
                                           subcategory=None,
@@ -1001,6 +1006,7 @@ class Ergast:
             constructor: Optional[str] = None,
             driver: Optional[str] = None,
             grid_position: Optional[int] = None,
+            results_position: Optional[int] = None,
             fastest_rank: Optional[int] = None,
             status: Optional[str] = None,
             result_type: Optional[Literal['pandas', 'raw']] = None,
@@ -1024,6 +1030,8 @@ class Ergast:
                 (default: all)
             driver: select a driver by its driver id (default: all)
             grid_position: select a grid position by its number (default: all)
+            results_position: select a finishing result by its position
+                (default: all)
             fastest_rank: select fastest by rank number (default: all)
             status: select by finishing status (default: all)
             result_type: Overwrites the default result type
@@ -1044,6 +1052,7 @@ class Ergast:
                      'constructor': constructor,
                      'driver': driver,
                      'grid_position': grid_position,
+                     'results_position': results_position,
                      'fastest_rank': fastest_rank,
                      'status': status}
 
@@ -1133,6 +1142,7 @@ class Ergast:
             constructor: Optional[str] = None,
             driver: Optional[str] = None,
             grid_position: Optional[int] = None,
+            results_position: Optional[int] = None,
             status: Optional[str] = None,
             result_type: Optional[Literal['pandas', 'raw']] = None,
             auto_cast: Optional[bool] = None,
@@ -1155,6 +1165,8 @@ class Ergast:
                 (default: all)
             driver: select a driver by its driver id (default: all)
             grid_position: select a grid position by its number (default: all)
+            results_position: select a finishing result by its position
+                (default: all)
             status: select by finishing status (default: all)
             result_type: Overwrites the default result type
             auto_cast: Overwrites the default value for ``auto_cast``
@@ -1174,6 +1186,7 @@ class Ergast:
                      'constructor': constructor,
                      'driver': driver,
                      'grid_position': grid_position,
+                     'results_position': results_position,
                      'status': status}
 
         return self._build_default_result(endpoint='sprint',
