@@ -36,12 +36,13 @@ DataFrame columns or Series values:
     A shorter event name usually containing the country or location but no
     no sponsor names. This name is required internally for proper api access.
 
-  - ``EventDate`` | :class:`datetime` |
+  - ``EventDate`` | :class:`pd.Timestamp` |
     The events reference date and time. This is used mainly internally.
     Usually, this is the same as the date of the last session.
 
   - ``EventFormat`` | :class:`str` |
-    The format of the event. One of 'conventional', 'sprint', 'testing'.
+    The format of the event. One of 'conventional', 'sprint',
+    'sprint_shootout', 'sprint_qualifying', 'testing'. See :ref:`event-formats`
 
   - ``Session*`` | :class:`str` |
     The name of the session. One of 'Practice 1', 'Practice 2', 'Practice 3',
@@ -53,14 +54,13 @@ DataFrame columns or Series values:
   - ``Session*Date`` | :class:`pd.Timestamp` |
     The date and time at which the session is scheduled to start or was
     scheduled to start as timezone-aware local timestamp.
-    (Timezone information is not available when the ``'ergast'`` backend
-    is used.)
+    (Timezone-aware local timestamps are not available when the ``'ergast'``
+    backend is used.)
     ``*`` denotes the number of the session (1, 2, 3, 4, 5).
 
   - ``Session*DateUtc`` | :class:`pd.Timestamp` |
     The date and time at which the session is scheduled to start or was
     scheduled to start as non-timezone-aware UTC timestamp.
-    (UTC timestamps are not available when the ``'ergast'`` backend is used.)
     ``*`` denotes the number of the session (1, 2, 3, 4, 5).
 
   - ``F1ApiSupport`` | :class:`bool` |
@@ -72,10 +72,10 @@ Supported Seasons
 .................
 
 FastF1 provides its own event schedule for the 2018 season and all later
-seasons. The schedule for the all seasons before 2018 is built using data from
+seasons. The schedule for all seasons before 2018 is built using data from
 the Ergast API. Only limited data is available for these seasons. Usage of the
-Ergast API can be enforced for all seasons, in which case the same limitations
-apply for the more recent seasons too.
+Ergast API can be enforced for all seasons by setting ``backend='ergast'``,
+in which case the same limitations apply for the more recent seasons too.
 
 **Exact scheduled starting times for all sessions**:
 Supported starting with the 2018 season.
@@ -90,13 +90,39 @@ provided for these. These assumptions will be incorrect for certain events!
 supported if usage of the Ergast API is enforced.
 
 
-Event Schedule
-..............
+.. _event-formats:
 
-- 'conventional': Practice 1, Practice 2, Practice 3, Qualifying, Race
-- 'sprint': Practice 1, Qualifying, Practice 2, Sprint, Race
-- 'testing': no fixed session order; usually three practice sessions on
-  three separate days
+Event Formats
+.............
+
+- **'conventional': Practice 1, Practice 2, Practice 3, Qualifying, Race**
+
+- **'sprint': Practice 1, Qualifying, Practice 2, Sprint, Race**
+
+  This is the original sprint format that was used in some races in 2021 and
+  2022. The Qualifying on friday set the grid for the Sprint on saturday.
+  The results from the Sprint set the grid for the Race on sunday.
+
+- **'sprint_shootout': Practice 1, Qualifying, Sprint Shootout, Sprint, Race**
+
+  This format was used in 2023. The Qualifying on friday sets the grid for the
+  main Race on sunday. The Sprint Shootout on saturday is held in similar
+  fashion to a normal Qualifying session and sets the grid for the Sprint that
+  takes place on saturday as well.
+
+- **'sprint_qualifying': Practice 1, Sprint Qualifying, Sprint, Qualifying,
+  Race**
+
+  This format is used starting from 2024. In general, it is similar to the
+  previous 'sprint_shootout' format, but the order of the sessions was changed
+  and 'Sprint Shootout' is renamed to 'Sprint Qualifying'. This means that
+  the Sprint Qualifying on friday is held in similar fashion to a normal
+  Qualifying and sets the grid for the Sprint on saturday. The Qualifying later
+  on saturday then sets the grid for the race on Sunday.
+
+- **'testing': no fixed session order**
+
+  usually three practice sessions on three separate days
 
 
 .. _SessionIdentifier:
@@ -108,16 +134,22 @@ Multiple event (schedule) related functions and methods make use of a session
 identifier to differentiate between the various sessions of one event.
 This identifier can currently be one of the following:
 
-    - session name abbreviation: ``'FP1', 'FP2', 'FP3', 'Q', 'S', 'SS', R'``
+    - session name abbreviation: ``'FP1', 'FP2', 'FP3', 'Q', 'S', 'SS', 'SQ',
+      'R'``
     - full session name: ``'Practice 1', 'Practice 2',
-      'Practice 3', 'Sprint', 'Sprint Shootout', 'Qualifying', 'Race'``;
+      'Practice 3', 'Sprint', 'Sprint Shootout', 'Sprint Qualifying',
+      'Qualifying', 'Race'``;
       provided names will be normalized, so that the name is
       case-insensitive
     - number of the session: ``1, 2, 3, 4, 5``
 
-Note that 'Sprint Qualifying' is now always called 'Sprint'.
-The event name will silently be corrected if you use 'Sprint Qualifying'/'SQ'
-instead of 'Sprint'/'S'.
+Note that the old ``'sprint'`` event format from 2021 and 2022 originally used
+the name 'Sprint Qualifying' before renaming these sessions to just 'Sprint'.
+The official schedule for 2021 now lists all these sessions as 'Sprint' and
+FastF1 will therefore return all these session as 'Sprint'. When querying for a
+specific session, FastF1 will also accept the 'Sprint Qualifying'/'SQ'
+identifier instead of only 'Sprint'/'S' for backwards compatibility.
+
 
 Functions for accessing schedule data
 -------------------------------------
@@ -146,14 +178,12 @@ API Reference
 .. autoclass:: EventSchedule
     :members:
     :undoc-members:
-    :show-inheritance:
     :autosummary:
 
 
 .. autoclass:: Event
     :members:
     :undoc-members:
-    :show-inheritance:
     :autosummary:
 
 """  # noqa: W605 invalid escape sequence (escaped space)
@@ -161,26 +191,34 @@ import collections
 import datetime
 import json
 import warnings
-from typing import Literal, Union, Optional
+from typing import (
+    Literal,
+    Optional,
+    Union
+)
 
 import dateutil.parser
-
-with warnings.catch_warnings():
-    warnings.filterwarnings(
-        'ignore', message="Using slow pure-python SequenceMatcher"
-    )
-    # suppress that warning, it's confusing at best here, we don't need fast
-    # sequence matching and the installation (on windows) requires some effort
-    from thefuzz import fuzz
-
 import pandas as pd
 
 import fastf1._api
-from fastf1.core import Session
 import fastf1.ergast
-from fastf1.logger import get_logger, soft_exceptions
+from fastf1 import __version_short__
+from fastf1.core import Session
+from fastf1.internals.fuzzy import fuzzy_matcher
+from fastf1.internals.pandas_base import (
+    BaseDataFrame,
+    BaseSeries
+)
+from fastf1.logger import (
+    get_logger,
+    soft_exceptions
+)
 from fastf1.req import Cache
-from fastf1.utils import recursive_dict_get, to_datetime, to_timedelta
+from fastf1.utils import (
+    recursive_dict_get,
+    to_datetime,
+    to_timedelta
+)
 
 
 _logger = get_logger(__name__)
@@ -198,6 +236,7 @@ _SESSION_TYPE_ABBREVIATIONS = {
 
 _SCHEDULE_BASE_URL = "https://raw.githubusercontent.com/" \
                      "theOehrly/f1schedule/master/"
+_HEADERS = {'User-Agent': f'FastF1/{__version_short__}'}
 
 
 def get_session(
@@ -230,7 +269,7 @@ def get_session(
 
             >>> get_session(2020, 'Austria', 'Qualifying')
 
-        Get the 3rd session if the 5th Grand Prix in 2021::
+        Get the 3rd session of the 5th Grand Prix in 2021::
 
             >>> get_session(2021, 5, 3)
 
@@ -246,9 +285,6 @@ def get_session(
             Some examples that will be correctly interpreted: 'bahrain',
             'australia', 'abudabi', 'monza'.
 
-            See :func:`get_event_by_name` for some further remarks on the
-            fuzzy matching.
-
         identifier: see :ref:`SessionIdentifier`
 
         backend: select a specific backend as data source, options:
@@ -317,7 +353,8 @@ def get_event(
         *,
         backend: Optional[Literal['fastf1', 'f1timing', 'ergast']] = None,
         force_ergast: bool = False,
-        strict_search: bool = False
+        strict_search: bool = False,
+        exact_match: bool = False
 ) -> "Event":
     """Create an :class:`~fastf1.events.Event` object for a specific
     season and gp.
@@ -356,9 +393,12 @@ def get_event(
         force_ergast: [Deprecated, use ``backend='ergast'``] Always use data
             from the ergast database to create the event schedule
 
-        strict_search: Match precisely the query, or default to
+        strict_search: This argument is deprecated and planned for removal,
+            use the equivalent ``exact_match`` instead
+
+        exact_match: Match precisely the query, or default to
             fuzzy search. If no event is found with
-            ``strict_search=True``, the function will return None
+            ``exact_match=True``, the function will return None
 
     .. versionadded:: 2.2
     """
@@ -366,8 +406,9 @@ def get_event(
                                   force_ergast=force_ergast,
                                   backend=backend)
 
-    if type(gp) is str:
-        event = schedule.get_event_by_name(gp, strict_search=strict_search)
+    if isinstance(gp, str):
+        event = schedule.get_event_by_name(
+            gp, strict_search=strict_search, exact_match=exact_match)
     else:
         event = schedule.get_event_by_round(gp)
 
@@ -492,7 +533,9 @@ def get_events_remaining(
         backend: Optional[Literal['fastf1', 'f1timing', 'ergast']] = None,
         force_ergast: bool = False
 ) -> 'EventSchedule':
-    """Create an :class:`~fastf1.events.EventSchedule` object for remaining season.
+    """
+    Create an :class:`~fastf1.events.EventSchedule` object for remaining
+    season.
 
     Args:
         dt: Optional DateTime to get events after.
@@ -524,13 +567,28 @@ def get_events_remaining(
     .. versionadded:: 2.3
     """
     if dt is None:
-        dt = datetime.datetime.now()
+        dt = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
 
     events = get_event_schedule(
         dt.year, include_testing=include_testing,
         force_ergast=force_ergast, backend=backend
     )
-    result = events.loc[events["EventDate"] >= dt]
+
+    if not include_testing:
+        result = events.loc[events["Session5DateUtc"] >= dt]
+        return result
+
+    indexes_to_drop = []
+    for idx, event in events.iterrows():
+        if not event.is_testing():
+            session_date = event["Session5DateUtc"]
+        else:
+            session_date = event["Session3DateUtc"]
+
+        if session_date <= dt:
+            indexes_to_drop.append(idx)
+
+    result = events.drop(index=indexes_to_drop)
     return result
 
 
@@ -539,7 +597,8 @@ def get_events_remaining(
                  _logger)
 def _get_schedule_ff1(year):
     response = Cache.requests_get(
-        _SCHEDULE_BASE_URL + f"schedule_{year}.json"
+        _SCHEDULE_BASE_URL + f"schedule_{year}.json",
+        headers=_HEADERS
     )
 
     data = dict()
@@ -582,22 +641,20 @@ def _get_schedule_ff1(year):
             data[f'session{j+1}_date'][i] = pd.Timestamp(date)
             data[f'session{j+1}_date_Utc'][i] = pd.Timestamp(date_utc)
 
-    str().capitalize()
-
     df = pd.DataFrame(data)
     # change column names from snake_case to UpperCamelCase
     col_renames = {col: ''.join([s.capitalize() for s in col.split('_')])
                    for col in df.columns}
     df = df.rename(columns=col_renames)
 
-    schedule = EventSchedule(df, year=year, force_default_cols=True)
+    schedule = EventSchedule(df, year=year, _force_default_cols=True)
     return schedule
 
 
 @soft_exceptions("F1 API schedule",
                  "Failed to load schedule from F1 API backend!",
                  _logger)
-def _get_schedule_from_f1_timing(year):
+def _get_schedule_from_f1_timing(year: int):
     # create an event schedule using data from the F1 API
     response = fastf1._api.season_schedule(f'/static/{year}/')
     data = collections.defaultdict(list)
@@ -608,29 +665,55 @@ def _get_schedule_from_f1_timing(year):
         data['EventName'].append(event['Name'])
         data['OfficialEventName'].append(event['OfficialName'])
 
-        n_events = min(len(event['Sessions']), 5)
+        # select only valid sessions
+        sessions = list()
+        for ses in event['Sessions']:
+            if (ses.get('Key') != -1) and ses.get('Name'):
+                sessions.append(ses)
+
+        n_events = min(len(sessions), 5)
         # number of events, usually 3 for testing, 5 for race weekends
         # in special cases there are additional unrelated events
 
-        if (n_events >= 4) and ('Sprint' in event['Sessions'][3]['Name']):
-            if event['Sessions'][3]['Name'] == 'Sprint Qualifying':
-                # fix for 2021 where Sprint was called Sprint Qualifying
-                event['Sessions'][3]['Name'] = 'Sprint'
-            data['EventFormat'].append('sprint')
-            data['RoundNumber'].append(event['Number'])
-        elif 'test' in event['Name'].lower():
+        if 'test' in event['Name'].lower():
             data['EventFormat'].append('testing')
             data['RoundNumber'].append(0)
-        else:
+
+        elif year <= 2020:
             data['EventFormat'].append('conventional')
             data['RoundNumber'].append(event['Number'])
 
+        elif year in (2021, 2022):
+            if sessions[3]['Name'] == 'Sprint Qualifying':
+                # fix for 2021 where Sprint was called Sprint Qualifying
+                sessions[3]['Name'] = 'Sprint'
+
+            if sessions[3]['Name'] == 'Sprint':
+                data['EventFormat'].append('sprint')
+            else:
+                data['EventFormat'].append('conventional')
+            data['RoundNumber'].append(event['Number'])
+
+        elif year == 2023:
+            if sessions[2]['Name'] == 'Sprint Shootout':
+                data['EventFormat'].append('sprint_shootout')
+            else:
+                data['EventFormat'].append('conventional')
+            data['RoundNumber'].append(event['Number'])
+
+        elif year >= 2024:
+            if sessions[1]['Name'] == 'Sprint Qualifying':
+                data['EventFormat'].append('sprint_qualifying')
+            else:
+                data['EventFormat'].append('conventional')
+            data['RoundNumber'].append(event['Number'])
+
         data['F1ApiSupport'].append(True)
 
         for i in range(0, 5):
             # parse the up to five sessions for each event
             try:
-                session = event['Sessions'][i]
+                session = sessions[i]
             except IndexError:
                 data[f'Session{i+1}'].append(None)
                 data[f'Session{i+1}Date'].append(None)
@@ -651,7 +734,7 @@ def _get_schedule_from_f1_timing(year):
         ev_date = ev_date.replace(hour=0, minute=0, second=0)
         data['EventDate'].append(ev_date)
 
-    schedule = EventSchedule(data, year=year, force_default_cols=True)
+    schedule = EventSchedule(data, year=year, _force_default_cols=True)
     return schedule
 
 
@@ -678,39 +761,64 @@ def _get_schedule_from_ergast(year) -> "EventSchedule":
                 f"{rnd.get('date', '')}T{rnd.get('time', '')}",
             ).tz_localize(None)
         except dateutil.parser.ParserError:
-            date = pd.NaT
+            date = pd.Timestamp(pd.NaT)
         data['EventDate'].append(date)
 
         if 'Sprint' in rnd:
-            data['EventFormat'].append("sprint")
-            data['Session1'].append('Practice 1')
+            # Ergast doesn't support sprint shootout format yet
+            if year in (2021, 2022):
+                _format = 'sprint'
+                session_names = ['Practice 1', 'Qualifying', 'Practice 2',
+                                 'Sprint', 'Race']
+            elif year == 2023:
+                _format = 'sprint_shootout'
+                session_names = ['Practice 1', 'Qualifying', 'Sprint Shootout',
+                                 'Sprint', 'Race']
+            else:
+                _format = 'sprint_qualifying'
+                session_names = ['Practice 1', 'Sprint Qualifying', 'Sprint',
+                                 'Qualifying', 'Race']
+
+            data['EventFormat'].append(_format)
+
+            data['Session1'].append(session_names[0])
             data['Session1DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=2))
-            data['Session2'].append('Qualifying')
+
+            data['Session2'].append(session_names[1])
             data['Session2DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=2))
-            data['Session3'].append('Practice 2')
+
+            data['Session3'].append(session_names[2])
             data['Session3DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=1))
-            data['Session4'].append('Sprint')
+
+            data['Session4'].append(session_names[3])
             data['Session4DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=1))
-            data['Session5'].append('Race')
+
+            data['Session5'].append(session_names[4])
             data['Session5DateUtc'].append(date)
+
         else:
             data['EventFormat'].append("conventional")
+
             data['Session1'].append('Practice 1')
             data['Session1DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=2))
+
             data['Session2'].append('Practice 2')
             data['Session2DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=2))
+
             data['Session3'].append('Practice 3')
             data['Session3DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=1))
+
             data['Session4'].append('Qualifying')
             data['Session4DateUtc'].append(
                 date.floor('D') - pd.Timedelta(days=1))
+
             data['Session5'].append('Race')
             data['Session5DateUtc'].append(date)
 
@@ -718,29 +826,30 @@ def _get_schedule_from_ergast(year) -> "EventSchedule":
         # simplified; this is only true most of the time
 
     df = pd.DataFrame(data)
-    schedule = EventSchedule(df, year=year, force_default_cols=True)
+    schedule = EventSchedule(df, year=year, _force_default_cols=True)
     return schedule
 
 
-class EventSchedule(pd.DataFrame):
+class EventSchedule(BaseDataFrame):
     """This class implements a per-season event schedule.
 
+    For detailed information about the information that is available for each
+    event, see `Event Schedule Data`_.
+
     This class is usually not instantiated directly. You should use
-    :func:`get_event_schedule` to get an event schedule for a specific
+    :func:`fastf1.get_event_schedule` to get an event schedule for a specific
     season.
 
     Args:
         *args: passed on to :class:`pandas.DataFrame` superclass
-        year (int): Championship year
-        force_default_cols (bool): Enforce that all default columns and only
-            the default columns exist
+        year: Championship year
         **kwargs: passed on to :class:`pandas.DataFrame` superclass
             (except 'columns' which is unsupported for the event schedule)
 
     .. versionadded:: 2.2
     """
 
-    _COL_TYPES = {
+    _COLUMNS = {
         'RoundNumber': int,
         'Country': str,
         'Location': str,
@@ -768,51 +877,14 @@ class EventSchedule(pd.DataFrame):
 
     _metadata = ['year']
 
-    _internal_names = pd.DataFrame._internal_names + ['base_class_view']
-    _internal_names_set = set(_internal_names)
+    def __init__(self, *args, year: int = 0, **kwargs):
 
-    def __init__(self, *args, year: int = 0,
-                 force_default_cols: bool = False, **kwargs):
-        if force_default_cols:
-            kwargs['columns'] = list(self._COL_TYPES)
         super().__init__(*args, **kwargs)
         self.year = year
 
-        # apply column specific dtypes
-        for col, _type in self._COL_TYPES.items():
-            if col not in self.columns:
-                continue
-            if self[col].isna().all():
-                if _type == 'datetime64[ns]':
-                    self[col] = pd.NaT
-                elif _type == object:
-                    self[col] = None
-                else:
-                    self[col] = _type()
-            self[col] = self[col].astype(_type)
-
-    def __repr__(self):
-        return self.base_class_view.__repr__()
-
     @property
-    def _constructor(self):
-        def _new(*args, **kwargs):
-            return EventSchedule(*args, **kwargs).__finalize__(self)
-
-        return _new
-
-    @property
-    def _constructor_sliced(self):
-        def _new(*args, **kwargs):
-            return Event(*args, **kwargs).__finalize__(self)
-
-        return _new
-
-    @property
-    def base_class_view(self):
-        """For a nicer debugging experience; can view DataFrame through
-        this property in various IDEs"""
-        return pd.DataFrame(self)
+    def _constructor_sliced_horizontal(self) -> type["Event"]:
+        return Event
 
     def is_testing(self):
         """Return `True` or `False`, depending on whether each event is a
@@ -849,38 +921,47 @@ class EventSchedule(pd.DataFrame):
 
     def _fuzzy_event_search(self, name: str) -> "Event":
 
+        def _remove_common_words(event_name):
+            common_words = ["formula 1", str(self.year), "grand prix", "gp"]
+            event_name = event_name.casefold()
+
+            for word in common_words:
+                event_name = event_name.replace(word, "")
+
+            return event_name
+
         def _matcher_strings(ev):
             strings = list()
-            if 'Location' in ev:
-                strings.append(ev['Location'])
-            if 'Country' in ev:
-                strings.append(ev['Country'])
-            if 'EventName' in ev:
-                strings.append(ev['EventName'].replace("Grand Prix", ""))
-            if 'OfficialEventName' in ev:
-                strings.append(ev['OfficialEventName']
-                               .replace("FORMULA 1", "")
-                               .replace(str(self.year), "")
-                               .replace("GRAND PRIX", ""))
+            if ('Location' in ev) and ev['Location']:
+                strings.append(ev['Location'].casefold())
+            if ('Country' in ev) and ev['Country']:
+                strings.append(ev['Country'].casefold())
+            if ('EventName' in ev) and ev['EventName']:
+                strings.append(_remove_common_words(ev["EventName"]))
+            if ('OfficialEventName' in ev) and ev['OfficialEventName']:
+                strings.append(_remove_common_words(ev["OfficialEventName"]))
             return strings
 
-        max_ratio = 0
-        index = 0
-        for i, event in self.iterrows():
-            ratio = max(
-                [fuzz.ratio(val.casefold(), name.casefold())
-                 for val in _matcher_strings(event)]
-            )
-            if ratio > max_ratio:
-                max_ratio = ratio
-                index = i
-        return self.loc[index]
+        user_input = name
+        name = _remove_common_words(name)
+
+        reference = [_matcher_strings(event) for _, event in self.iterrows()]
+
+        index, exact = fuzzy_matcher(name, reference)
+        event = self.iloc[index]
+
+        if not exact:
+            _logger.warning(f"Correcting user input '{user_input}' to "
+                            f"'{event.EventName}'")
+
+        return event
 
     def get_event_by_name(
             self,
             name: str,
             *,
-            strict_search: bool = False
+            strict_search: bool = False,
+            exact_match: bool = False
     ) -> "Event":
         """Get an :class:`Event` by its name.
 
@@ -889,7 +970,7 @@ class EventSchedule(pd.DataFrame):
         name and officialName of each event. This is not guaranteed to return
         the correct result. You should therefore always check if the function
         actually returns the event you had wanted.
-        To gurantee the function returns the event queried, toggle
+        To guarantee the function returns the event queried, toggle
         strict_search, which will only return an event if its event name
         matches (non case sensitive) the query string.
 
@@ -903,31 +984,40 @@ class EventSchedule(pd.DataFrame):
                 ``.get_event_by_name("british")`` and
                 ``.get_event_by_name("silverstone")`` will both return the
                 event for the British Grand Prix.
-            strict_search: Search only for exact query matches
+            strict_search: This argument is deprecated and planned for removal.
+                Use the equivalent ``exact_match`` instead
+            exact_match: Search only for exact query matches
                 instead of using fuzzy search. For example,
-                ``.get_event_by_name("British Grand Prix", strict_search=True)`` # noqa: E501
+                ``.get_event_by_name("British Grand Prix",
+                exact_match=True)``
                 will return the event for the British Grand Prix, whereas
-                ``.get_event_by_name("British", strict_search=True)``
+                ``.get_event_by_name("British", exact_match=True)``
                 will return ``None``
         """
-
         if strict_search:
+            warnings.warn(("strict_search is deprecated and planned for "
+                           "removal, use the equivalent exact_match instead"),
+                          FutureWarning)
+        if strict_search or exact_match:
             return self._strict_event_search(name)
         else:
             return self._fuzzy_event_search(name)
 
 
-class Event(pd.Series):
+class Event(BaseSeries):
     """This class represents a single event (race weekend or testing event).
 
     Each event consists of one or multiple sessions, depending on the type
     of event and depending on the event format.
 
+    For detailed information about the information that is available for each
+    event, see `Event Schedule Data`_.
+
     This class is usually not instantiated directly. You should use
-    :func:`get_event` or similar to get a specific event.
+    :func:`fastf1.get_event` or similar to get a specific event.
 
     Args:
-          year (int): Championship year
+          year: Championship year
     """
     _metadata = ['year']
 
@@ -935,13 +1025,6 @@ class Event(pd.Series):
         super().__init__(*args, **kwargs)
         self.year = year
 
-    @property
-    def _constructor(self):
-        def _new(*args, **kwargs):
-            return Event(*args, **kwargs).__finalize__(self)
-
-        return _new
-
     def is_testing(self) -> bool:
         """Return `True` or `False`, depending on whether this event is a
         testing event."""
@@ -982,8 +1065,12 @@ class Event(pd.Series):
                 except KeyError:
                     raise ValueError(f"Invalid session type '{identifier}'")
 
-            # 'Sprint' is called 'Sprint Qualifying' only in 2021
-            if session_name == 'Sprint Qualifying':
+            # 'Sprint' was originally called 'Sprint Qualifying' only in the
+            # old 'sprint' event format and renamed later; support the old
+            # name for backwards compatibility by silently correcting to the
+            # new name
+            if ((session_name == 'Sprint Qualifying')
+                    and (self.year in (2021, 2022))):
                 session_name = 'Sprint'
 
             if session_name not in self.values:
@@ -1078,6 +1165,10 @@ class Event(pd.Series):
         """Return the sprint shootout session."""
         return self.get_session('Sprint Shootout')
 
+    def get_sprint_qualifying(self) -> "Session":
+        """Return the sprint qualifying session."""
+        return self.get_session('Sprint Qualifying')
+
     def get_practice(self, number: int) -> "Session":
         """Return the specified practice session.
         Args:
