@@ -1,6 +1,10 @@
 import argparse
 import sys
-from fastf1.livetiming.client import SignalRClient, messages_from_raw
+
+from fastf1.livetiming.client import (
+    SignalRClient,
+    messages_from_raw
+)
 
 
 def save(args):
@@ -11,7 +15,7 @@ def save(args):
 
 
 def convert(args):
-    with open(args.input, 'r') as infile:
+    with open(args.input) as infile:
         messages = infile.readlines()
     data, ec = messages_from_raw(messages)
     with open(args.output, 'w') as outfile:
